translate.misc.context

Package translate :: Package misc :: Module context |
[hide private]
[frames] | no frames]

# Module context

source code

Functions | [hide private]
with_(mgr, body) A function to mimic the with statement introduced in Python 2.5 | source code

Variables | [hide private]
| __package__ = ``'``translate.misc``'``

Imports: sys

Function Details | [hide private]

### with_(mgr, body) | source code
A function to mimic the with statement introduced in Python 2.5 The code below was taken from http://www.python.org/dev/peps/pep-0343/